@@ -52,16 +52,15 @@ Returns HASH of HASH of nodes. First level is indexed by type
 =cut
 sub run
 {
+    confess "poll: $!" unless my $poll = IO::Poll->new();
+
     local $| = 1;
     local $/ = undef;
 
     my $self = shift;
-
-    confess "poll: $!" unless my $poll = IO::Poll->new();
-
+    my @node = keys %$self;
     my ( %run, %result, %buffer, %busy ) = ( %RUN, @_ );
     my ( $log, $max, $timeout, $input ) = @run{ qw( log max timeout input ) };
-    my @node = keys %$self;
 
     $input ||= -t STDIN ? '' : <STDIN>;
 
@@ -85,14 +84,15 @@ sub run
             my $node = shift @node;
             my %inet =
             (
-                PeerAddr => $node, Blocking => 0,
+                PeerAddr => $node, Blocking => 0, Timeout => $timeout,
                 Proto => 'tcp', Type => SOCK_STREAM,
             );
 
             my $sock = $self->{$node}
-                ? IO::Socket::INET->new( %inet ) : IO::Socket::UNIX->new( %inet );
+                ? IO::Socket::INET->new( %inet )
+                : IO::Socket::UNIX->new( %inet );
 
-            unless ( $sock || $!{EINPROGRESS} )
+            unless ( $sock )
             {
                 push @{ $result{error}{ "socket: $!" } }, $node;
                 next;
